@@ -8,9 +8,7 @@ import s4u.sqlalchemy.events
 def init_sqlalchemy(engine):
     """Initialise the SQLAlchemy models. This must be called before using
     using any of the SQLAlchemy managed the tables or classes in the model."""
-
-    sm = orm.sessionmaker(bind=engine, extension=ZopeTransactionExtension())
-    meta.Session = orm.scoped_session(sm)
+    meta.Session.configure(bind=engine)
     meta.metadata.bind = engine
 
 
