@@ -9,13 +9,18 @@ class Mapping(TypeDecorator):
 
     When using a PostgreSQL backend the native HSTORE type is used. On
     other databases values are stored as JSON-encoded string.
+
+    Please note that this does not support any of the operators available
+    for the `PostgreSQL HSTORE type
+    <http://docs.sqlalchemy.org/en/rel_0_9/dialects/postgresql.html#sqlalchemy.dialects.postgresql.HSTORE`_
+    on other dialects.
     """
 
     impl = postgresql.HSTORE
 
     def load_dialect_impl(self, dialect):
         if dialect.name == 'postgresql':
-            return dialect.type_descriptor(postgresql.HSTORE())
+            return self.impl
         else:
             return dialect.type_descriptor(VARCHAR)
 
