@@ -1,10 +1,13 @@
 """SQLAlchemy Metadata and Session object"""
+from sqlalchemy import orm
 from sqlalchemy import schema
 from sqlalchemy.ext.declarative import declarative_base
+from zope.sqlalchemy import ZopeTransactionExtension
 
 #: SQLAlchemy session manager.  Updated by
 # :py:func:`s4u.sqlalchemy.init_sqlalchemy`.
-Session = None
+Session = orm.scoped_session(
+        orm.sessionmaker(extension=ZopeTransactionExtension()))
 
 #: Global metadata. If you have multiple databases with overlapping table
 #: names, you'll need a metadata for each database
